Welcome to DAX's documentation!
===============================

DAX is Distributed Automation for `XNAT <http://xnat.org/>`_

DAX allows you to:

- store analyzed imaging data on XNAT (datatypes)
- extract information from XNAT via scripts (Xnat_tools)
- run pipelines on your data in XNAT via a cluster (processors)


Installation
------------

Install the latest release with `pip <https://pypi.org/project/pip/>`_:

.. code::

   pip install dax


Contents:

.. toctree::
   :maxdepth: 3
   
   dax_installation
   dax_xnat_dataypes_install
   dax
   dax_manager
   contributors
   how_to_contribute
   faq
   processors
   